# 画廊

展示使用 ABSESpy 进行基于智能体建模的社区示例和研究项目。

> **注意**: 研究项目示例在其各自的仓库中维护。请查看[官方示例](official.md)页面了解 ABSESpy 内置的示例。

## 社区示例

即将推出！如果您使用 ABSESpy 构建了模型并希望分享，请提交 pull request 或在我们的 [GitHub 仓库](https://github.com/SongshGeo/ABSESpy)上开启一个 issue。

## 研究项目

### 已发表模型

使用 ABSESpy 的研究模型单独维护。请联系作者以访问特定的研究代码库。

### 如何贡献

如果您想展示基于 ABSESpy 的研究：

1. 在 [GitHub](https://github.com/SongshGeo/ABSESpy/issues) 上开启一个 issue
2. 提供简要描述和仓库链接
3. 审核通过后，我们会将其添加到此画廊

